#2D plot stuff
library(FactoMineR)
library(plotrix)
library("factoextra")
library(ggplot2)
#library(corrplot)
library(grid)
library(ggrepel)
library(ellipse)

soundGroups=read.csv("allMaster.csv", header = TRUE, row.names = 1, sep = ",")
res.ca = CA(soundGroups, ncp=10)

res.hcpc<-HCPC(res.ca, cluster.CA="rows")

fviz_gg<-fviz_cluster(res.hcpc, ggtheme = theme_bw(), main="", labelsize = 12, ellipse.type = "norm")

title.text<-element_text(size=20, face="bold")
tick.text<-element_text(size=15)


#colCoord<-res.ca$col$coord
#write.csv(colCoord, file="wordCoord.csv", row.names=TRUE) #<- add word types to this


df=read.csv("wordCoord.csv", header = TRUE, sep = ",")
head(df)


df_ell <- data.frame()
for(g in levels(fviz_gg$data$clust)){
df_ell <- rbind(df_ell, cbind(as.data.frame(with(fviz_gg$data[fviz_gg$data$clust==g,], ellipse(cor(x, y), 
                                         scale=c(sd(x),sd(y)), 
                                         centre=c(mean(x),mean(y))))),group=g))
}


p2<-ggplot()+
geom_text_repel(data=df, aes(x=Dim.1, y=Dim.2, label=Word, colour=Type),show.legend = FALSE)+
geom_point(data=df, aes(x=Dim.1, y=Dim.2, colour=Type, shape=Type))+
geom_path(data=df_ell, aes(x=x, y=y, linetype=group), size=1)+
theme_bw()+
labs(x="Dimension 1", y="Dimension 2")+
coord_cartesian(xlim = c(-2, 2),ylim = c(-2, 2)) +
scale_fill_manual(values = c("source"="deepskyblue","signal"="firebrick","affect-judgement"="chartreuse4"))+
theme(
	axis.title=title.text,
	axis.text=tick.text,
	panel.grid	= element_blank(),
	panel.border=element_blank(),
	axis.line = element_line(colour = "black"),
	legend.position = c(0.8, 0.8), 
	legend.text=tick.text,
	legend.title=tick.text
)		

df=read.csv("flucCor.csv", header = TRUE, sep = ",")
head(df)


p4<-ggplot(df, aes(Dim1, Fluc))+
geom_point()+
theme_bw()+
labs(x="Dimension 1", y="Flucturation Amplitude")+
geom_smooth(method = "lm", se=FALSE, color="black")+
theme(
	axis.title=title.text,
	axis.text=tick.text,
	panel.grid	= element_blank(),
	panel.border=element_blank(),
	axis.line = element_line(colour = "black"),
	legend.position = c(0.8, 0.8), 
	legend.text=tick.text,
	legend.title=tick.text
)		

cor.test(df$Dim1, df$Fluc, type="spearman", alternative="greater")

p5<-ggplot(df, aes(Dim2, Bright))+
geom_point()+
theme_bw()+
labs(x="Dimension 2", y="Brightness")+
geom_smooth(method = "lm", se=FALSE, color="black")+
theme(
	axis.title=title.text,
	axis.text=tick.text,
	panel.grid	= element_blank(),
	panel.border=element_blank(),
	axis.line = element_line(colour = "black"),
	legend.position = c(0.8, 0.8), 
	legend.text=tick.text,
	legend.title=tick.text
)		

shapiro.test(df$Bright)

cor.test(df$Dim2, df$Bright, type="pearson", alternative="greater")


#------------
setEPS()
postscript("engines_2D.eps", family="Times", width=7, height=21)


grid.newpage()
pushViewport(viewport(layout = grid.layout(nrow=3, ncol=1)))

print(p2, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
grid.text("A", vp = viewport(layout.pos.row = 1, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))
print(p4, vp = viewport(layout.pos.row = 2, layout.pos.col = 1))
grid.text("B", vp = viewport(layout.pos.row = 2, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))
print(p5, vp = viewport(layout.pos.row = 3, layout.pos.col = 1))
grid.text("C", vp = viewport(layout.pos.row = 3, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))



dev.off()